pynrc.simul.apt.ReadAPTXML
==========================

.. currentmodule:: pynrc.simul.apt

.. autoclass:: ReadAPTXML
   :members:
   :inherited-members:
   :show-inheritance:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ReadAPTXML.__init__
      ~ReadAPTXML.add_exposure
      ~ReadAPTXML.append_to_exposures_dictionary
      ~ReadAPTXML.get_tracking_type
      ~ReadAPTXML.read_coarsephasing_template
      ~ReadAPTXML.read_commissioning_template
      ~ReadAPTXML.read_finephasing_template
      ~ReadAPTXML.read_generic_imaging_template
      ~ReadAPTXML.read_globalalignment_template
      ~ReadAPTXML.read_miri_coronagraphy_template
      ~ReadAPTXML.read_nircam_coronagraphy_template
      ~ReadAPTXML.read_nircam_grism_time_series
      ~ReadAPTXML.read_nircam_imaging_time_series
      ~ReadAPTXML.read_nircam_wfss_template
      ~ReadAPTXML.read_niriss_ami_template
      ~ReadAPTXML.read_niriss_wfss_template
      ~ReadAPTXML.read_parallel_exposures
      ~ReadAPTXML.read_xml
      ~ReadAPTXML.separate_pupil_and_filter
   
   

   
   
   